==> open-cluster-management-apps-model-6.6.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/AnsibleJobsStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface AnsibleJobsStatusFluent<A extends AnsibleJobsStatusFluent<A>> extends Fluent<A>{
  public String getLastposthookjob();
  public A withLastposthookjob(String lastposthookjob);
  public Boolean hasLastposthookjob();
  public String getLastprehookjob();
  public A withLastprehookjob(String lastprehookjob);
  public Boolean hasLastprehookjob();
  public A addToPosthookjobshistory(Integer index,String item);
  public A setToPosthookjobshistory(Integer index,String item);
  public A addToPosthookjobshistory(java.lang.String... items);
  public A addAllToPosthookjobshistory(Collection<String> items);
  public A removeFromPosthookjobshistory(java.lang.String... items);
  public A removeAllFromPosthookjobshistory(Collection<String> items);
  public List<String> getPosthookjobshistory();
  public String getPosthookjobshistory(Integer index);
  public String getFirstPosthookjobshistory();
  public String getLastPosthookjobshistory();
  public String getMatchingPosthookjobshistory(Predicate<String> predicate);
  public Boolean hasMatchingPosthookjobshistory(Predicate<String> predicate);
  public A withPosthookjobshistory(List<String> posthookjobshistory);
  public A withPosthookjobshistory(java.lang.String... posthookjobshistory);
  public Boolean hasPosthookjobshistory();
  public A addToPrehookjobshistory(Integer index,String item);
  public A setToPrehookjobshistory(Integer index,String item);
  public A addToPrehookjobshistory(java.lang.String... items);
  public A addAllToPrehookjobshistory(Collection<String> items);
  public A removeFromPrehookjobshistory(java.lang.String... items);
  public A removeAllFromPrehookjobshistory(Collection<String> items);
  public List<String> getPrehookjobshistory();
  public String getPrehookjobshistory(Integer index);
  public String getFirstPrehookjobshistory();
  public String getLastPrehookjobshistory();
  public String getMatchingPrehookjobshistory(Predicate<String> predicate);
  public Boolean hasMatchingPrehookjobshistory(Predicate<String> predicate);
  public A withPrehookjobshistory(List<String> prehookjobshistory);
  public A withPrehookjobshistory(java.lang.String... prehookjobshistory);
  public Boolean hasPrehookjobshistory();
  
}

==> open-cluster-management-apps-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/AnsibleJobsStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface AnsibleJobsStatusFluent<A extends AnsibleJobsStatusFluent<A>> extends Fluent<A>{
  public String getLastposthookjob();
  public A withLastposthookjob(String lastposthookjob);
  public Boolean hasLastposthookjob();
  public String getLastprehookjob();
  public A withLastprehookjob(String lastprehookjob);
  public Boolean hasLastprehookjob();
  public A addToPosthookjobshistory(int index,String item);
  public A setToPosthookjobshistory(int index,String item);
  public A addToPosthookjobshistory(java.lang.String... items);
  public A addAllToPosthookjobshistory(Collection<String> items);
  public A removeFromPosthookjobshistory(java.lang.String... items);
  public A removeAllFromPosthookjobshistory(Collection<String> items);
  public List<String> getPosthookjobshistory();
  public String getPosthookjobshistory(int index);
  public String getFirstPosthookjobshistory();
  public String getLastPosthookjobshistory();
  public String getMatchingPosthookjobshistory(Predicate<String> predicate);
  public Boolean hasMatchingPosthookjobshistory(Predicate<String> predicate);
  public A withPosthookjobshistory(List<String> posthookjobshistory);
  public A withPosthookjobshistory(java.lang.String... posthookjobshistory);
  public Boolean hasPosthookjobshistory();
  public A addToPrehookjobshistory(int index,String item);
  public A setToPrehookjobshistory(int index,String item);
  public A addToPrehookjobshistory(java.lang.String... items);
  public A addAllToPrehookjobshistory(Collection<String> items);
  public A removeFromPrehookjobshistory(java.lang.String... items);
  public A removeAllFromPrehookjobshistory(Collection<String> items);
  public List<String> getPrehookjobshistory();
  public String getPrehookjobshistory(int index);
  public String getFirstPrehookjobshistory();
  public String getLastPrehookjobshistory();
  public String getMatchingPrehookjobshistory(Predicate<String> predicate);
  public Boolean hasMatchingPrehookjobshistory(Predicate<String> predicate);
  public A withPrehookjobshistory(List<String> prehookjobshistory);
  public A withPrehookjobshistory(java.lang.String... prehookjobshistory);
  public Boolean hasPrehookjobshistory();
  
}
